@@ -22,8 +22,7 @@
    Authors: Jan Arne Petersen <jpetersen@uni-bonn.de>
 */
 
-#ifndef NAUTILUS_PREFERENCES_WINDOW_H
-#define NAUTILUS_PREFERENCES_WINDOW_H
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -32,6 +31,4 @@ G_BEGIN_DECLS
 
 void nautilus_preferences_window_show(GtkWindow *window);
 
-G_END_DECLS
-
-#endif /* NAUTILUS_PREFERENCES_WINDOW_H */
+G_END_DECLS
\ No newline at end of file
