@@ -111,6 +111,7 @@ struct _NautilusWindow
 
     /* Notifications */
     AdwToastOverlay *toast_overlay;
+    AdwToast *last_undo_toast;
 
     /* Toolbar */
     GtkWidget *toolbar;
@@ -963,6 +964,11 @@ places_sidebar_drag_perform_drop_cb (NautilusGtkPlacesSidebar *sidebar,
     char *dest_uri;
     GList *source_uri_list;
 
+    if (source_file_list == NULL)
+    {
+        return;
+    }
+
     dest_uri = g_file_get_uri (dest_file);
     source_uri_list = build_uri_list_from_gfile_list (source_file_list);
 
@@ -1269,12 +1275,19 @@ nautilus_window_on_undo_changed (NautilusFileUndoManager *manager,
             }
         }
 
+        if (window->last_undo_toast != NULL)
+        {
+            adw_toast_dismiss (window->last_undo_toast);
+            g_clear_weak_pointer (&window->last_undo_toast);
+        }
+
         if (popup_toast)
         {
             toast = adw_toast_new (label);
             adw_toast_set_button_label (toast, _("Undo"));
             adw_toast_set_action_name (toast, "win.undo");
             adw_toast_set_priority (toast, ADW_TOAST_PRIORITY_HIGH);
+            g_set_weak_pointer (&window->last_undo_toast, toast);
             adw_toast_overlay_add_toast (window->toast_overlay, toast);
         }
     }
